@@ -1,5 +1,13 @@
+/*
+ * This program is copyright Alec Muffett 1993, portions copyright other authors.
+ * The authors disclaim all responsibility or liability with respect to it's usage
+ * or its effect upon hardware or computer systems.
+ */
+
 #include <stdio.h>
 #include <limits.h>
+#include <string.h>
+#include <locale.h>
 
 #define IN_CRACKLIB
 #include "config.h"
@@ -9,9 +17,17 @@
 int
 main(int argc, char **argv)
 {
-	char buf[LINE_MAX], *why;
+	char buf[LINE_MAX];
+	const char *why;
 	int i;
 
+	setlocale(LC_ALL, "");
+
+#ifdef ENABLE_NLS
+	bindtextdomain(PACKAGE, LOCALEDIR);
+	textdomain(PACKAGE);
+#endif
+
 	while (fgets(buf, sizeof(buf), stdin) != NULL) {
 		while (((i = strlen(buf)) > 0) && (i > 0)) {
 			if (strchr("\r\n", buf[i - 1]) != NULL) {
