@@ -1,12 +1,11 @@
 /*
- * This program is copyright Alec Muffett 1993. The author disclaims all 
- * responsibility or liability with respect to it's usage or its effect 
- * upon hardware or computer systems, and maintains copyright as set out 
- * in the "LICENCE" document which accompanies distributions of Crack v4.0 
- * and upwards.
+ * This program is copyright Alec Muffett 1993, portions copyright other authors.
+ * The authors disclaim all responsibility or liability with respect to it's usage
+ * or its effect upon hardware or computer systems.
  */
 
 #include <stdio.h>
+#include <string.h>
 
 #define IN_CRACKLIB
 #include "config.h"
@@ -18,17 +17,18 @@ main(argc, argv)
     int argc;
     char *argv[];
 {
-    uint32_t readed;
-    uint32_t wrote;
+    unsigned long readed;
+    unsigned long wrote;
     PWDICT *pwp;
-    char buffer[STRINGSIZE];
+    char buffer[STRINGSIZE], prev[STRINGSIZE];
     char *file;
+    char opened = 0;
 
     if (argc <= 1)
     {
 	file = DEFAULT_CRACKLIB_DICT;
     }
-    else 
+    else
     {
         file = argv[1];
     }
@@ -40,13 +40,8 @@ main(argc, argv)
 	return (-1);
     }
 
-    if (!(pwp = PWOpen(file, "w")))
-    {
-	perror(file);
-	return (-1);
-    }
-
     wrote = 0;
+    prev[0] = '\0';
 
     for (readed = 0; fgets(buffer, STRINGSIZE, stdin); /* nothing */)
     {
@@ -62,6 +57,25 @@ main(argc, argv)
 	    continue;
 	}
 
+	if (!opened)
+	{
+	    if (!(pwp = PWOpen(file, "w")))
+	    {
+	        perror(file);
+	        return (-1);
+	    }
+	    opened = 1;
+	}
+
+	/*
+	 * If this happens, strcmp() in FindPW() in packlib.c will be unhappy.
+	 */
+	if (strcmp(buffer, prev) < 0)
+	{
+	    fprintf(stderr, "warning: input out of order: '%s' should not follow '%s' (line %lu)\n", buffer, prev, readed);
+	}
+	strcpy(prev, buffer);
+
 	if (PutPW(pwp, buffer))
 	{
 	    fprintf(stderr, "error: PutPW '%s' line %luy\n", buffer, readed);
@@ -70,7 +84,8 @@ main(argc, argv)
 	wrote++;
     }
 
-    PWClose(pwp);
+    if (opened)
+        PWClose(pwp);
 
     printf("%lu %lu\n", readed, wrote);
 
