@@ -1,9 +1,7 @@
 /*
- * This program is copyright Alec Muffett 1993. The author disclaims all 
- * responsibility or liability with respect to it's usage or its effect 
- * upon hardware or computer systems, and maintains copyright as set out 
- * in the "LICENCE" document which accompanies distributions of Crack v4.0 
- * and upwards.
+ * This program is copyright Alec Muffett 1993, portions copyright other authors.
+ * The authors disclaim all responsibility or liability with respect to it's usage
+ * or its effect upon hardware or computer systems.
  */
 
 #include <stdio.h>
@@ -22,7 +20,7 @@ main ()
     PWDICT *pwp;
     char buffer[STRINGSIZE];
 
-    if (!(pwp = PWOpen (NULL, "r")))
+    if (!(pwp = PWOpen (DEFAULT_CRACKLIB_DICT, "r")))
     {
 	perror ("PWOpen");
 	return (-1);
@@ -34,9 +32,9 @@ main ()
     {
 	char *c;
 
-	sscanf (buffer, "%lu", &i);
+	sscanf (buffer, "%u", &i);
 
-	printf ("(word %ld) ", i);
+	printf ("(word %d) ", i);
 
 	if (!(c = (char *) GetPW (pwp, i)))
 	{
